@@ -50,6 +50,8 @@ typedef enum fmReturn_enum
     FM_ST_PARTITION_NAME_NOT_IN_USE      = -20, //!< Partition name is specified but the referenced partition could not be found
     FM_ST_PARTITION_ID_NAME_MISMATCH     = -21, //!< Valid partition id and name specified but they refer to different partitions  
     FM_ST_NOT_READY                      = -22, //!< Fabric Manager is not ready to serve GFM API requests.
+    FM_ST_RESOURCE_USED_IN_THIS_PARTITION = -23, //!< Resource is already in use in this partition
+    FM_ST_RESOURCE_USED_IN_ANOTHER_PARTITION = -24, //!< Resource is already in use in another partition
 } fmReturn_t;
 
 typedef void *fmHandle_t;   //!< Identifier for Fabric Manager API interface Handle
